;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: PRS16_1.asm
;;   Version: 3.4, Updated on 2008/9/17 at 16:15:18
;;  Generated by PSoC Designer ???
;;
;;  DESCRIPTION: PRS16 User Module software implementation file
;;               for the 22/24/25/26/27xxx PSoC family of devices.
;;
;;  NOTE: User Module APIs conform to the fastcall16 convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API functions
;;        returns. For Large Memory Model devices it is also the caller's 
;;        responsibility to perserve any value in the CUR_PP, IDX_PP, MVR_PP and 
;;        MVW_PP registers. Even though some of these registers may not be modified
;;        now, there is no guarantee that will remain the case in future releases.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress MicroSystems 2000-2003. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "PRS16_1.inc"

;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------
export   PRS16_1_Start
export  _PRS16_1_Start
export   PRS16_1_Stop
export  _PRS16_1_Stop
export   PRS16_1_WriteSeed
export  _PRS16_1_WriteSeed
export   PRS16_1_WritePolynomial
export  _PRS16_1_WritePolynomial
export   PRS16_1_wReadPRS
export  _PRS16_1_wReadPRS

;--------------------------------------------
;       WARNING WARNING WARNING
; The following exports are for backwards
; compatibility only and should not be used
; for new designs.
export  wPRS16_1_ReadPRS
export _wPRS16_1_ReadPRS
;--------------------------------------------

;-----------------------------------------------
;  Constant Definitions
;-----------------------------------------------
bfCONTROL_REG_START_BIT:   equ   1        ; Control register start bit

AREA UserModules (ROM, REL)

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PRS16_1_Start
;
;  DESCRIPTION:
;     Starts the PRS16 user module.  The PRS will begin computing the PRS
;     POLYNOMIAL when data is clocked in.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:
;
;  RETURNS:
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;  THEORY of OPERATION or PROCEDURE:
;     Set the start bit in the Control register of the LSB block.
;
;-----------------------------------------------------------------------------
 PRS16_1_Start:
_PRS16_1_Start:
   RAM_PROLOGUE RAM_USE_CLASS_1
   or    REG[PRS16_1_CONTROL_REG_LSB], bfCONTROL_REG_START_BIT
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PRS16_1_Stop
;
;  DESCRIPTION:
;     Disables PRS16 operation.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:  None
;
;  RETURNS:    None
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;    Writing to the Seed register will cause the seed value to be latched into
;    the Shift register.
;
;  THEORY of OPERATION or PROCEDURE:
;     Clear the start bit in the Control register of the LSB block.
;
;-----------------------------------------------------------------------------
 PRS16_1_Stop:
_PRS16_1_Stop:
   RAM_PROLOGUE RAM_USE_CLASS_1
   and   REG[PRS16_1_CONTROL_REG_LSB], ~bfCONTROL_REG_START_BIT
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PRS16_1_WriteSeed
;
;  DESCRIPTION:
;     Initializes the PRS polynomial function with a starting seed value.
;     The PRS16 User module is stopped while the Seed value is updated and
;     upon exit, its previous start state is restored.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:
;     wSeedValue - the seed value to initialize the polynomial function.
;     MSB passed in X
;     LSB passed in A
;
;  RETURNS:  None
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;     PRS16 user module is stopped while the seed is updated.
;
;  THEORY of OPERATION or PROCEDURE:
;     Set the seed value in the Seed register.
;
;-----------------------------------------------------------------------------
 PRS16_1_WriteSeed:
_PRS16_1_WriteSeed:
   RAM_PROLOGUE RAM_USE_CLASS_1
   ;save the input parameters
   push  X
   push  A

   ;get and save the current start state
   mov   A, REG[PRS16_1_CONTROL_REG_LSB]
   mov   X, A

   ;stop the PRS16
   and   REG[PRS16_1_CONTROL_REG_LSB], ~bfCONTROL_REG_START_BIT

   ; Load the Seed value into the Seed register
   pop   A
   mov   reg[PRS16_1_SEED_REG_LSB], A
   pop   A
   mov   reg[PRS16_1_SEED_REG_MSB], A

   ; restore the start state
   mov   A, X
   mov   REG[PRS16_1_CONTROL_REG_LSB], A
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PRS16_1_WritePolynomial
;
;  DESCRIPTION:
;     Initializes the PRS polynomial value.
;     The PRS16 User module is stopped while the polynomial value is updated and
;     upon exit, its previous start state is restored.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:
;     wPolynomial - the polynomial to load into the polynomial register
;     MSB passed in X
;     LSB passed in A
;
;  RETURNS:
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;     PRS16 user module is stopped while the polynomial is updated.
;
;  THEORY of OPERATION or PROCEDURE:
;     Set the polynomial value in the Polynomial register
;
;-----------------------------------------------------------------------------
 PRS16_1_WritePolynomial:
_PRS16_1_WritePolynomial:
   RAM_PROLOGUE RAM_USE_CLASS_1
   ;save the input parameters
   push  X
   push  A

   ;get and save the current start state
   mov   A, REG[PRS16_1_CONTROL_REG_LSB]
   mov   X, A

   ;stop the PRS16
   and   REG[PRS16_1_CONTROL_REG_LSB], ~bfCONTROL_REG_START_BIT

   ; Load the polynomial into the PRS16 Polynomial register
   pop   A
   mov   reg[PRS16_1_POLY_REG_LSB], A
   pop   A
   mov   reg[PRS16_1_POLY_REG_MSB], A

   ; restore the start state
   mov   A, X
   mov   REG[PRS16_1_CONTROL_REG_LSB], A
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PRS16_1_wReadPRS
;
;  DESCRIPTION:
;     Reads the currently computed PRS polynomial function value.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: None
;
;  RETURNS:
;     wPRSValue - PRS value read.
;        MSB returned in X
;        LSB returned in A
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;     The seed value is lost.
;
;  THEORY of OPERATION or PROCEDURE:
;     1) Read the Shift register - PRS value is transferred to Seed register
;     2) Read the Seed register.
;
;-----------------------------------------------------------------------------
 PRS16_1_wReadPRS:
_PRS16_1_wReadPRS:
 wPRS16_1_ReadPRS:    ; For backwards compatibility, do not use!
_wPRS16_1_ReadPRS:    ; For backwards compatibility, do not use!
   RAM_PROLOGUE RAM_USE_CLASS_1
   ;-------------
   ;  MSB BYTE
   ;-------------
   ; Read the Shift register.  This causes the current
   ;  PRS computed number to be transferred to the Seed register.
   mov   A, reg[PRS16_1_SHIFT_REG_MSB]

   ; Read the PRS computed value
   mov   A, reg[PRS16_1_SEED_REG_MSB]
   mov   X, A

   ;-------------
   ;  LSB BYTE
   ;-------------
   ; Read the Shift register.  This causes the current
   ;  PRS computed number to be transferred to the Seed register.
   mov   A, reg[PRS16_1_SHIFT_REG_LSB]

   ; Read the PRS computed value
   mov   A, reg[PRS16_1_SEED_REG_LSB]
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

; End of File PRS16_1.asm
