//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules

#define	OSC_SAW		1
#define	OSC_PRS		0

#define	OSC_F125	1
#define	OSC_F250	0

#define	C16_F125	5999
#define	C16_F250	2999

#define	INT_F125	1500
#define	INT_F250	3000


const unsigned char tmval[5][3] = {
					{61,  93, PGA_1_G0_87},	// 1210Hz 798Hz
					{33, 249, PGA_1_G0_75},	// 2206Hz 300Hz
					{49, 249, PGA_1_G0_93},	// 1500Hz 300Hz
					{37, 149, PGA_1_G0_62},	// 1974Hz 500Hz
					{106,187, PGA_1_G0_75}	//  701Hz 399Hz
				};

const unsigned char wavedat[16] = {0x00, 0x04, 0x08, 0x0c,
				   0x10, 0x14, 0x18, 0x1c,
				   0x20, 0x24, 0x28, 0x2c,
				   0x30, 0x34, 0x38, 0x3c};

unsigned char	oscmode;
unsigned char	oscfreq,p_oscfreq;
unsigned char	dacdat;
unsigned char	waveptr;
unsigned int	intcount;

#pragma interrupt_handler Counter16_1_ISR
void Counter16_1_ISR(void)
{
	DAC6_1_WriteStall(dacdat);
	if (oscmode == OSC_SAW) {
		dacdat = wavedat[waveptr];
		waveptr = (waveptr + 1) & 0xf;
	}
	if (oscmode == OSC_PRS) {
		dacdat = PRS16_1_wReadPRS() & 0x3f;
		if (dacdat == 0x3f)
			dacdat = 0x3e;
	}
	if (intcount)
		intcount--;
}

unsigned char tmval_ptr;
void set_tmval(void)
{
	M8C_DisableGInt;
	if (oscfreq == OSC_F125)
		intcount = INT_F125;
	else	intcount = INT_F250;
	M8C_EnableGInt;
	if (oscfreq != p_oscfreq) {
		Counter16_1_Stop();
		if (oscfreq == OSC_F125)
			Counter16_1_WritePeriod(C16_F125);
		else	Counter16_1_WritePeriod(C16_F250);
		Counter16_1_Start();
		p_oscfreq = oscfreq;
	}
	if (tmval_ptr < 4)
		tmval_ptr++;
	else	tmval_ptr = 0;
	Timer8_1_Stop();
	Timer8_2_Stop();
	Timer8_1_WritePeriod(tmval[tmval_ptr][0]);
	Timer8_2_WritePeriod(tmval[tmval_ptr][1]);
	PGA_1_SetGain(tmval[tmval_ptr][2]);
	Timer8_1_Start();
	Timer8_2_Start();
}

void main()
{
	PRT0DR |= 0x41;
	oscmode = OSC_SAW;
	oscfreq = OSC_F125;
	p_oscfreq = OSC_F250;
	waveptr = 0;
	dacdat = 0;
	Timer8_1_Start();
	Timer8_2_Start();
	PGA_1_Start(PGA_1_HIGHPOWER);
	PGA_2_Start(PGA_2_HIGHPOWER);
	PGA_3_Start(PGA_3_HIGHPOWER);
	ACB01CR2 = (ACB01CR2 & ~0x1c) | 0x14;
	BPF2_1_Start(BPF2_1_HIGHPOWER);
	BPF2_2_Start(BPF2_2_HIGHPOWER);
	DAC6_1_Start(DAC6_1_HIGHPOWER);
	PRS16_1_WritePolynomial(0xd008);	// 16 15 13 4:1101 0000 0000 1000
	PRS16_1_WriteSeed(0xffff);
	PRS16_1_Start();
	tmval_ptr = 4;
	set_tmval();
	Counter16_1_EnableInt();
	while(1) {
		if (PRT0DR & 0x40)
			oscmode = OSC_SAW;
		else	oscmode = OSC_PRS;
		if (PRT0DR & 0x01)
			oscfreq = OSC_F125;
		else	oscfreq = OSC_F250;
		if (!intcount)
			set_tmval();
	}
}
